<?php
/**
 * Plugin Name: Vercel Trigger
 * Plugin URI: https://devhuset.no
 * Description: A plugin to save and trigger Vercel webhooks for deployment.
 * Version: 1.0.9
 * Author: Devhuset AS
 * Author URI: https://devhuset.no
 * Text Domain: vercel-trigger
 * Domain Path: /languages
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

if (!defined('DEV_CURRENT_VERSION')) {
    define('DEV_CURRENT_VERSION', '1.0.9');
}

if (!defined('DEV_PLUGIN_DIR')) {
    define('DEV_PLUGIN_DIR', WP_PLUGIN_DIR . '/' . plugin_basename(__DIR__));
}

if (!defined('DEV_RELATIVE_PLUGIN_DIR')) {
    define('DEV_RELATIVE_PLUGIN_DIR', plugin_basename(__DIR__));
}

if (!defined('DEV_PLUGIN_FILE')) {
    define('DEV_PLUGIN_FILE', WP_PLUGIN_DIR . '/' . plugin_basename(__FILE__));
}

if (!defined('DEV_RELATIVE_PLUGIN_FILE')) {
    define('DEV_RELATIVE_PLUGIN_FILE', plugin_basename(__FILE__));
}

require DEV_PLUGIN_DIR . '/update.php';

add_action('admin_menu', 'vercel_trigger_menu');

function vercel_trigger_menu()
{
    add_menu_page(
        'Vercel Trigger', // Page title
        'Vercel Trigger', // Menu title
        'manage_options', // Capability
        'vercel-trigger', // Menu slug
        'vercel_trigger_page' // Function to display the page
    );
}

function vercel_trigger_page()
{
    // Check if user is allowed to access this page
    if (!current_user_can('manage_options')) {
        return;
    } ?>

    <div class="wrap">
        <h1>Vercel Trigger</h1>

        <?php if ('POST' === $_SERVER['REQUEST_METHOD']) {
            if (isset($_POST['action']) && check_admin_referer('vercel_trigger_action', 'vercel_trigger_nonce')) {
                if ($_POST['action'] === 'reset_url') {
                    delete_option('vercel_webhook_url');
                    echo '<div class="updated"><p>Webhook URL reset.</p></div>';
                } elseif ($_POST['action'] === 'save_url') {
                    update_option('vercel_webhook_url', sanitize_text_field($_POST['vercel_webhook_url']));
                    echo '<div class="updated"><p>Webhook URL saved.</p></div>';
                } elseif ($_POST['action'] === 'trigger_webhook') {
                    $webhook_url = get_option('vercel_webhook_url');
                    if ($webhook_url) {
                        $response = wp_remote_post($webhook_url);
                        if (is_wp_error($response)) {
                            echo '<div class="error"><p>Failed to trigger webhook: ' . $response->get_error_message() . '</p></div>';
                        } else {
                            echo '<div class="updated"><p>Webhook triggered successfully.</p></div>';
                        }
                    } else {
                        echo '<div class="error"><p>No webhook URL to trigger. Please set a URL first.</p></div>';
                    }
                }
            }
        }

        $webhook_url = get_option('vercel_webhook_url', '');
        ?>

        <table class="form-table">
            <tr valign="top">
                <th scope="row">Vercel Webhook URL</th>
                <td style="display: flex; gap: 0.5rem;">
                    <?php if (empty($webhook_url)): ?>
                        <form method="post" action="">
                            <?php wp_nonce_field('vercel_trigger_action', 'vercel_trigger_nonce'); ?>
                            <input type="text" name="vercel_webhook_url" value="" size="50">
                            <input type="hidden" name="action" value="save_url">
                            <input type="submit" class="button button-primary" value="Save URL">
                        </form>
                    <?php else: ?>
                        <form method="post" action="">
                            <?php wp_nonce_field('vercel_trigger_action', 'vercel_trigger_nonce'); ?>
                            <input type="hidden" name="action" value="trigger_webhook">
                            <input type="submit" class="button button-primary" value="Trigger Webhook">
                        </form>
                        <form method="post" action="">
                            <?php wp_nonce_field('vercel_trigger_action', 'vercel_trigger_nonce'); ?>
                            <input type="submit" class="button" value="Reset URL">
                            <input type="hidden" name="action" value="reset_url">
                        </form>
                    <?php endif; ?>
                </td>
            </tr>
        </table>
    </div>

    <?php
}